about summary refs log tree commit diff
path: root/wcsmbs/tst-wscanf-binary-c2x.c
diff options
context:
space:
mode:
Diffstat (limited to 'wcsmbs/tst-wscanf-binary-c2x.c')
-rw-r--r--wcsmbs/tst-wscanf-binary-c2x.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/wcsmbs/tst-wscanf-binary-c2x.c b/wcsmbs/tst-wscanf-binary-c2x.c
index 8049ce5f2f..06d99f235e 100644
--- a/wcsmbs/tst-wscanf-binary-c2x.c
+++ b/wcsmbs/tst-wscanf-binary-c2x.c
@@ -1,4 +1,4 @@
 /* Test wscanf functions with C2X binary integers (wide strings,
    no extensions).
    Copyright (C) 2022-2024 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
@@ -18,14 +18,14 @@
    <https://www.gnu.org/licenses/>.  */
 
 /* Some versions of GCC supported for building glibc do not support
-   -std=c2x.  */
+   -std=c23 or -std=c2x.  */
 #undef _GNU_SOURCE
-#define _ISOC2X_SOURCE
+#define _ISOC23_SOURCE
 
 #define CHAR wchar_t
 #define FNW w
 #define L_(C) L ## C
-#define TEST_C2X 1
-#define STD "c2x"
+#define TEST_C23 1
+#define STD "c23"
 
 #include "../stdio-common/tst-scanf-binary-main.c"
@@ -1,4 +1,4 @@
-/* Test wscanf functions with C2X binary integers (wide strings,
+/* Test wscanf functions with C23 binary integers (wide strings,
    no extensions).
    Copyright (C) 2022-2024 Free Software Foundation, Inc.